library pico_log.impl;

import 'dart:io';
import 'dart:mirrors';

import 'package:logging/logging.dart';
import 'package:ansicolor/ansicolor.dart';

typedef String _Stringer(LogRecord);

String nameOf(Type T, bool simple) => simple
    ? reflectClass(T).simpleName.toString()
    : reflectClass(T).qualifiedName.toString();

_Stringer fmt;

void onData(LogRecord rec) {
  var msg = fmt(rec);
  var level = rec.level.name;
  switch (level) {
    default:
      stdout.writeln('$level: $msg');
  }
}

void colorize(LogRecord rec) {
  var msg = fmt(rec);
  var level = rec.level.name;
  switch (level) {
    case 'INFO':
      stdout.writeln(_cyan('$msg'));
      break;
    case 'WARNING':
      stderr.writeln(_yellow('$msg'));
      break;
    case 'SEVERE':
    case 'SHOUT':
      stderr.writeln(_red('$msg'));
      break;
    default:
      stdout.writeln('$msg');
  }
}

_Stringer toMsg = (LogRecord rec) =>
    '${rec.time}: [${rec.loggerName}] ${rec.message}';
_Stringer noTimestamps = (LogRecord rec) =>
    '[${rec.loggerName}] ${rec.message}';

final _cyan = new AnsiPen()..cyan(bold: true);
final _yellow = new AnsiPen()..yellow(bold: true);
final _red = new AnsiPen()..red(bold: true);
